{
  config,
  lib,
  pkgs,
  ...
}:

{
  imports = [ ];

  options.me = {
    rpcs3.enable = lib.mkOption {
      type = lib.types.bool;
      default = false;
      example = true;
      description = "Whether we want to install rpcs3.";
    };
  };

  config = lib.mkIf config.me.rpcs3.enable (
    lib.mkMerge [
      (lib.mkIf config.me.graphical {
        environment.systemPackages = with pkgs; [
          rpcs3
        ];

        security.pam.loginLimits = [
          {
            domain = "@wheel";
            item = "memlock";
            type = "hard";
            value = "unlimited";
          }
          {
            domain = "@wheel";
            item = "memlock";
            type = "soft";
            value = "unlimited";
          }
        ];

        # .config/rpcs3/config.yml
        # .config/rpcs3/GuiConfigs/CurrentSettings.ini

        environment.persistence."/persist" = lib.mkIf (!config.me.buildingIso) {
          hideMounts = true;
          users.talexander = {
            directories = [
              {
                # Location of ROMs.
                directory = ".config/rpcs3/games";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
              {
                directory = ".config/rpcs3/dev_hdd0";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
              {
                directory = ".config/rpcs3/dev_hdd1";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
              {
                directory = ".config/rpcs3/savestates";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
              {
                directory = ".config/rpcs3/dev_usb000";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
              {
                # Seems to be where the firmware is installed.
                directory = ".config/rpcs3/dev_flash";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
            ];
          };
        };

        environment.persistence."/state" = lib.mkIf (!config.me.buildingIso) {
          hideMounts = true;
          users.talexander = {
            directories = [
              {
                # Game saves
                directory = ".cache/rpcs3";
                user = "talexander";
                group = "talexander";
                mode = "0755";
              }
            ];
          };
        };
      })
    ]
  );
}
